/*
 * Asterisk -- An open source telephony toolkit.
 *
 * Copyright (C) 2011, Odin.
 *
 * Odin <name@odints.com>
 *
 * See http://www.asterisk.org for more information about
 * the Asterisk project. Please do not directly contact
 * any of the maintainers of this project for assistance;
 * the project provides a web site, mailing lists and IRC
 * channels for your use.
 *
 * This program is free software, distributed under the terms of
 * the GNU General Public License Version 2. See the LICENSE file
 * at the top of the source tree.
 */

/*! \file
 * 
 * \brief N64 configure 
 *
 * \author Odin <name@odints.com>
 */ 

#include "asterisk.h"

ASTERISK_FILE_VERSION(__FILE__, "$Revision: $")

#include "asterisk/io.h"
#include "asterisk/file.h"
#include "asterisk/module.h"
#include "asterisk/logger.h"
#include "asterisk/config.h"

static int load_module(void)
{
  struct ast_config *cfg;
  struct ast_variable *v;
  struct ast_flags config_flags = { 0 };
  char *psPrevCategory = 0;


  ast_log(LOG_NOTICE, "n64 configure starts.\n");
  
  /* read configuration */
  if (!(cfg = ast_config_load2("n64.conf", "n64", config_flags))) {
    ast_log(LOG_NOTICE, "Configuration file '%s' not found!\n", "n64.conf");
    return AST_MODULE_LOAD_SUCCESS;
  }
  if (cfg == CONFIG_STATUS_FILEUNCHANGED) {
    ast_clear_flag(&config_flags, CONFIG_FLAG_FILEUNCHANGED);
    cfg = ast_config_load2("n64.conf", "res_fax", config_flags);
  }


  do{
    psPrevCategory = ast_category_browse(cfg, psPrevCategory);
    if( psPrevCategory ){
      char sSpanCom[256];
      char pSpanFileName[256];
      char *psMac = 0;
      char *psIf = 0;
      char *psCh = 0;
      FILE *pSpanFile = NULL;
      for (v = ast_variable_browse(cfg, psPrevCategory); v; v = v->next) {
        if (!strcasecmp(v->name, "mac")) {
          psMac = v->value;
        }
        if (!strcasecmp(v->name, "if")) {
          psIf = v->value;
        }
        if (!strcasecmp(v->name, "ch")) {
          psCh = v->value;
        }
      }
      if( psMac && psIf && psCh ){
        sprintf(sSpanCom, "mac=%s if=%s ch=%s", psMac, psIf, psCh);
        sprintf(pSpanFileName, "/proc/otxdahdin64/spans/%s", psPrevCategory);
        ast_log(LOG_NOTICE, "n64: %s FILE:%s\n", sSpanCom, pSpanFileName);
        pSpanFile= fopen(pSpanFileName, "wt");
        if( pSpanFile != NULL ){
          fwrite( sSpanCom, strlen(pSpanFile), 1, pSpanFile);
          fclose( pSpanFile );
          pSpanFile = NULL;
        }else{
          ast_log(LOG_NOTICE, "n64: Fail to open FILE:%s\n", pSpanFileName);
        }
      }
      // "/proc/dahdi/%s"
    }
  }while( psPrevCategory );
  
  return AST_MODULE_LOAD_SUCCESS;
}


static int unload_module(void)
{
  ast_log(LOG_NOTICE, "n64 configure stops.\n");
  return 0;
}

AST_MODULE_INFO_STANDARD(ASTERISK_GPL_KEY, "N64 configure");
